# arbejdstimer

[![license](https://img.shields.io/github/license/sthagen/arbejdstimer.svg?style=flat)](https://github.com/sthagen/arbejdstimer/blob/default/LICENSE)
[![version](https://img.shields.io/pypi/v/arbejdstimer.svg?style=flat)](https://pypi.python.org/pypi/arbejdstimer/)
[![downloads](https://img.shields.io/pypi/dm/arbejdstimer.svg?style=flat)](https://pypi.python.org/pypi/arbejdstimer/)
[![wheel](https://img.shields.io/pypi/wheel/arbejdstimer.svg?style=flat)](https://pypi.python.org/pypi/arbejdstimer/)
[![supported-versions](https://img.shields.io/pypi/pyversions/arbejdstimer.svg?style=flat)](https://pypi.python.org/pypi/arbejdstimer/)
[![supported-implementations](https://img.shields.io/pypi/implementation/arbejdstimer.svg?style=flat)](https://pypi.python.org/pypi/arbejdstimer/)

Working hours (Danish arbejdstimer) or not?

## Status

Experimental.

**Note**: The default branch is `default`.
